Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1098)

Unified Diff: chrome/browser/ui/ash/lock_screen_client.h

Issue 2903353003: Adding mojo calls for easy unlock service (Closed)
Patch Set: comments and rebase Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/ash/lock_screen_client.h
diff --git a/chrome/browser/ui/ash/lock_screen_client.h b/chrome/browser/ui/ash/lock_screen_client.h
index 7e0d13434645794800f2e30328182bb5d3c1a232..bb5d543105bc807007223435f4734e160be4a167 100644
--- a/chrome/browser/ui/ash/lock_screen_client.h
+++ b/chrome/browser/ui/ash/lock_screen_client.h
@@ -1,4 +1,4 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -16,19 +16,44 @@ class LockScreenClient : public ash::mojom::LockScreenClient {
LockScreenClient();
~LockScreenClient() override;
+ // Handles method calls coming from ash into chrome.
+ class Delegate {
+ public:
+ Delegate();
+ virtual ~Delegate();
+ virtual void HandleAttemptUnlock(const AccountId& account_id) = 0;
+ virtual void HandleHardlockPod(const AccountId& account_id) = 0;
+ virtual void HandleRecordClickOnLockIcon(const AccountId& account_id) = 0;
+
+ private:
+ DISALLOW_COPY_AND_ASSIGN(Delegate);
+ };
+
static LockScreenClient* Get();
// ash::mojom::LockScreenClient:
void AuthenticateUser(const AccountId& account_id,
const std::string& hashed_password,
bool authenticated_by_pin) override;
+ void AttemptUnlock(const AccountId& account_id) override;
+ void HardlockPod(const AccountId& account_id) override;
+ void RecordClickOnLockIcon(const AccountId& account_id) override;
- // Wrappers around the mojom::SystemTray interface.
+ // Wrappers around the mojom::LockScreen interface.
void ShowErrorMessage(int32_t login_attempts,
const std::string& error_text,
const std::string& help_link_text,
int32_t help_topic_id);
void ClearErrors();
+ void ShowUserPodCustomIcon(const AccountId& account_id,
+ ash::mojom::UserPodCustomIconOptionsPtr icon);
+ void HideUserPodCustomIcon(const AccountId& account_id);
+ void SetAuthType(const AccountId& account_id,
+ ash::mojom::AuthType auth_type,
+ const base::string16& initial_value);
+ void LoadUsers(std::unique_ptr<base::ListValue> users_list, bool show_guest);
+
+ void SetDelegate(Delegate* delegate);
private:
// Lock screen mojo service in ash.
@@ -36,6 +61,7 @@ class LockScreenClient : public ash::mojom::LockScreenClient {
// Binds this object to the client interface.
mojo::Binding<ash::mojom::LockScreenClient> binding_;
+ Delegate* delegate_ = nullptr;
DISALLOW_COPY_AND_ASSIGN(LockScreenClient);
};
« no previous file with comments | « chrome/browser/chromeos/login/user_selection_screen_proxy.cc ('k') | chrome/browser/ui/ash/lock_screen_client.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698